@@ -1,21 +1,23 @@
 """Contains classes for supported devices."""
 from __future__ import annotations
 
+from typing import Final
+
 from .constants import (
     DATA_FRAMES,
     DATA_MODE,
     DEVICE_DATA,
     DEVICE_PARAMS,
     MODES,
-    MODULE_PANEL,
+    MODULE_A,
 )
 from .helpers.base_device import BaseDevice
 from .helpers.parameter import Parameter
 from .mixers import MixersCollection
 from .storage import FrameBucket
 
-ECOMAX_ADDRESS: int = 0x45
-ECOSTER_ADDRESS: int = 0x51
+ECOMAX_ADDRESS: Final = 0x45
+ECOSTER_ADDRESS: Final = 0x51
 
 
 class Device(BaseDevice):
@@ -28,20 +30,20 @@ class Device(BaseDevice):
         data -- device data
         parameters -- editable parameters
         """
+        self.__dict__["bucket"] = FrameBucket()
+        self.__dict__["mixers"] = MixersCollection(address=self.address)
+        self.__dict__["product"] = None
+        self.__dict__["uid"] = None
+        self.__dict__["password"] = None
+        self.__dict__["struct"] = []
+        self.__dict__["_is_on"] = False
         super().__init__(data, parameters)
-        self.product = None
-        self.uid = None
-        self.password = None
-        self.struct = []
-        self.bucket = FrameBucket()
-        self.mixers = MixersCollection()
-        self._is_on = False
 
     def set_data(self, data: dict) -> None:
         """Sets device data.
 
         Keyword arguments:
-        data -- device immutable attributes
+        data -- immutable device attributes
         """
         self.bucket.fill(data[DATA_FRAMES])
         for name, value in data.items():
@@ -69,8 +71,8 @@ class Device(BaseDevice):
     @property
     def software(self) -> str | None:
         """Returns software version."""
-        if MODULE_PANEL in self._data:
-            return self._data[MODULE_PANEL]
+        if MODULE_A in self._data:
+            return self._data[MODULE_A]
 
         return None
 
@@ -172,7 +174,7 @@ class DevicesCollection:
         """Gets device by address.
 
         Keyword arguments:
-        address -- int address of device
+        address -- address of device
         """
         if address not in self._instances:
             try:
