@@ -10,18 +10,12 @@ from collections.abc import Callable
 import logging
 import os
 import sys
+from typing import Final
 
 import serial_asyncio
 
-from .constants import (
-    DATA_MIXERS,
-    DEFAULT_IP,
-    DEFAULT_NETMASK,
-    READER_TIMEOUT,
-    RECONNECT_TIMEOUT,
-    WLAN_ENCRYPTION,
-)
-from .devices import DevicesCollection
+from .constants import DATA_MIXERS, DEFAULT_IP, DEFAULT_NETMASK, WLAN_ENCRYPTION
+from .devices import ECOMAX_ADDRESS, DevicesCollection
 from .exceptions import ChecksumError, FrameTypeError, LengthError
 from .frame import Frame
 from .frames import requests, responses
@@ -29,6 +23,9 @@ from .stream import FrameReader, FrameWriter
 
 _LOGGER = logging.getLogger(__name__)
 
+READER_TIMEOUT: Final = 5
+RECONNECT_TIMEOUT: Final = 30
+
 
 class EcoNET(ABC):
     """Base ecoNET connection class."""
@@ -86,11 +83,13 @@ class EcoNET(ABC):
         elif frame.is_type(responses.UID):
             device.uid = frame.data["UID"]
             device.product = frame.data["reg_name"]
+            writer.queue(requests.Password(recipient=frame.sender))
 
         elif frame.is_type(responses.Password):
             device.password = frame.data
 
         elif frame.is_type(responses.RegData, responses.CurrentData):
+            frame.struct = device.struct
             device.set_data(frame.data)
             if DATA_MIXERS in frame.data:
                 device.mixers.set_data(frame.data[DATA_MIXERS])
@@ -104,12 +103,10 @@ class EcoNET(ABC):
         elif frame.is_type(responses.DataStructure):
             device.struct = frame.data
 
+        elif frame.is_type(requests.CheckDevice):
+            writer.queue(frame.response(data=self._net))
+
         writer.collect(device.changes)
-        if writer.queue_is_empty():
-            # If queue is empty, send device available frame.
-            writer.queue(
-                responses.DeviceAvailable(recipient=frame.sender, data=self._net)
-            )
 
     async def _read(self, reader: FrameReader) -> None:
         """Handles connection reads."""
@@ -144,7 +141,9 @@ class EcoNET(ABC):
             await self.writer.close()
 
         await asyncio.sleep(RECONNECT_TIMEOUT)
-        return await self.connect()
+        reader, writer = await self.connect()
+        await writer.write(requests.StartMaster(recipient=ECOMAX_ADDRESS))
+        return reader, writer
 
     async def task(
         self, callback: Callable[DevicesCollection, EcoNET], interval: int = 1
@@ -156,7 +155,6 @@ class EcoNET(ABC):
         interval -- user-defined update interval in seconds
         """
         reader, self.writer = await self.connect()
-        self.writer.queue(requests.Password())
         self._callback_task = asyncio.create_task(self._callback(callback, interval))
         await self._read(reader)
 
@@ -181,7 +179,7 @@ class EcoNET(ABC):
         self, ip: str, netmask: str = DEFAULT_NETMASK, gateway: str = DEFAULT_IP
     ) -> None:
         """Sets eth parameters to pass to devices.
-        Used for informational purpoises only.
+        Used for informational purposes only.
 
         Keyword arguments:
         ip -- ip address of eth device
