@@ -3,17 +3,14 @@
 from __future__ import annotations
 
 from asyncio import StreamReader, StreamWriter
+from typing import Final
 
 from . import util
-from .constants import (
-    BROADCAST_ADDRESS,
-    ECONET_ADDRESS,
-    HEADER_SIZE,
-    READER_BUFFER_SIZE,
-)
 from .exceptions import ChecksumError, LengthError
 from .factory import FrameFactory
-from .frame import Frame, Request
+from .frame import BROADCAST_ADDRESS, ECONET_ADDRESS, HEADER_SIZE, Frame, Request
+
+READER_BUFFER_SIZE: Final = 1000
 
 
 class FrameWriter:
@@ -25,7 +22,7 @@ class FrameWriter:
         """Creates instance of FrameWriter.
 
         Keyword arguments:
-        writer -- instance of asyncio.StreamWriter
+        writer -- instance of stream writer
         """
         self.writer = writer
         self._queue = []
@@ -44,7 +41,7 @@ class FrameWriter:
             if isinstance(frame, Frame):
                 self._queue.append(frame)
 
-    def queue_is_empty(self) -> bool:
+    def is_empty(self) -> bool:
         """Checks if write queue is empty."""
         return len(self._queue) == 0
 
@@ -69,11 +66,11 @@ class FrameWriter:
         Keyword arguments:
         frame -- Frame instance to add
         """
-        self.writer.write(frame.to_bytes())
+        self.writer.write(frame.bytes)
         await self.writer.drain()
 
     async def close(self) -> None:
-        """Closes StreamWriter."""
+        """Closes stream writer."""
         self.writer.close()
         await self.writer.wait_closed()
 
@@ -87,7 +84,7 @@ class FrameReader:
         """Creates FrameReader instance.
 
         Keyword arguments:
-        reader -- instance of asyncio.StreamReader
+        reader -- instance of stream reader
         """
         self.reader = reader
 
