@@ -6,6 +6,13 @@ import struct
 
 DEGREE_SIGN = "\N{DEGREE SIGN}"
 unpack_float = struct.Struct("<f").unpack
+unpack_char = struct.Struct("<b").unpack
+unpack_short = struct.Struct("<h").unpack
+unpack_int = struct.Struct("<i").unpack
+unpack_uint = struct.Struct("<I").unpack
+unpack_double = struct.Struct("<d").unpack
+unpack_int64 = struct.Struct("<q").unpack
+unpack_uint64 = struct.Struct("<Q").unpack
 pack_header = struct.Struct("<BH4B").pack_into
 unpack_header = struct.Struct("<BH4B").unpack_from
 
@@ -14,7 +21,7 @@ def crc(data: bytearray) -> int:
     """Calculates frame checksum.
 
     Keyword arguments:
-    data - data to calculate checksum for
+    data -- data to calculate checksum for
     """
     return functools.reduce(lambda x, y: x ^ y, data)
 
@@ -23,7 +30,7 @@ def to_hex(data: bytearray) -> str:
     """Converts bytearray to list of hex strings.
 
     Keyword arguments:
-    data - data for conversion
+    data -- data for conversion
     """
     return [f"{data[i]:02X}" for i in range(0, len(data))]
 
@@ -56,8 +63,8 @@ def unpack_parameter(data: bytearray, offset: int, size: int = 1) -> (int, int,
     return value, min_, max_
 
 
-def ip_to_bytes(address: str) -> bytearray:
-    """Converts ip address to bytes.
+def ip4_to_bytes(address: str) -> bytearray:
+    """Converts ip4 address to bytes.
 
     Keyword arguments:
     address -- ip address as string
@@ -65,15 +72,33 @@ def ip_to_bytes(address: str) -> bytearray:
     return socket.inet_aton(address)
 
 
-def ip_from_bytes(data: bytearray) -> str:
-    """Converts ip address from bytes to string representation.
+def ip4_from_bytes(data: bytearray) -> str:
+    """Converts ip4 address from bytes to string representation.
 
     Keyword arguments:
-    data -- 4 bytes to convert
+    data -- address bytes to convert
     """
     return socket.inet_ntoa(data)
 
 
+def ip6_to_bytes(address: str) -> bytearray:
+    """Converts ip6 address to bytes.
+
+    Keyword arguments:
+    address -- ip address as string
+    """
+    return socket.inet_pton(socket.AF_INET6, address)
+
+
+def ip6_from_bytes(data: bytearray) -> str:
+    """Converts ip4 address from bytes to string representation.
+
+    Keyword arguments:
+    data -- address bytes to convert
+    """
+    return socket.inet_ntop(socket.AF_INET6, data)
+
+
 def merge(defaults: dict, options: dict) -> dict:
     """Merges two dictionary with options overriding defaults.
 
@@ -116,11 +141,7 @@ def uid_stamp(message: str) -> str:
         int_ = ord(byte)
         crc_ = crc_ ^ int_
         for _ in range(8):
-            if crc_ & 1:
-                crc_ = (crc_ >> 1) ^ 0xA001
-                continue
-
-            crc_ = crc_ >> 1
+            crc_ = (crc_ >> 1) ^ 0xA001 if crc_ & 1 else crc_ >> 1
 
     return chr(crc_ % 256) + chr((crc_ // 256) % 256)
 
